<!DOCTYPE html>
<html lang="en">
    <head>
    </head>
    <body>
        <h2>Mosaiq comparison between RCCC and NBCCC</h2>
        
        <h3>NBCCC fields tested</h3>
        {{ nbccc_fields }}
        
        <h3>RCCC fields tested</h3>
        {{ rccc_fields }}
        
        <h3>Results</h3>
        {{ results }}
    </body>
</html>